@@ -71,6 +71,17 @@ impl Command for History {
                     })
                     .ok()
             }
+            // this variant should never happen, the config value is handled in the `UpdateFromValue` impl
+            #[cfg(not(feature = "sqlite"))]
+            HistoryFileFormat::Sqlite => {
+                return Err(ShellError::GenericError {
+                    error: "Could not open history reader".into(),
+                    msg: "SQLite is not supported".to_string(),
+                    span: Some(call.head),
+                    help: "Compile Nushell with `sqlite` feature".to_string().into(),
+                    inner: vec![],
+                });
+            }
             HistoryFileFormat::Plaintext => {
                 FileBackedHistory::with_file(history.max_size as usize, history_path.clone())
                     .map(|inner| {
@@ -104,6 +115,17 @@ impl Command for History {
                     history_path,
                 ))?
                 .into_pipeline_data(head, signals)),
+            // this variant should never happen, the config value is handled in the `UpdateFromValue` impl
+            #[cfg(not(feature = "sqlite"))]
+            HistoryFileFormat::Sqlite => {
+                return Err(ShellError::GenericError {
+                    error: "Could not open history reader".into(),
+                    msg: "SQLite is not supported".to_string(),
+                    span: Some(call.head),
+                    help: "Compile Nushell with `sqlite` feature".to_string().into(),
+                    inner: vec![],
+                });
+            }
             #[cfg(feature = "sqlite")]
             HistoryFileFormat::Sqlite => Ok(history_reader
                 .and_then(|h| {
