@@ -3,12 +3,13 @@ use nu_color_config::{color_record_to_nustyle, lookup_ansi_color_style};
 use nu_engine::{compile, eval_call};
 use nu_parser::flatten_expression;
 use nu_protocol::{
-    BlockId, DeclId, IntoSpanned, PipelineData, ShellError, Span, Spanned, SuggestionKind, Type,
-    Value, VarId,
+    BlockId, DeclId, GetSpan, IntoSpanned, PipelineData, Record, ShellError, Span, Spanned,
+    SuggestionKind, Type, Value, VarId,
     ast::{Argument, Call, Expr, Expression},
     debugger::WithoutDebug,
     engine::{Closure, EngineState, Stack, StateWorkingSet},
 };
+use nu_utils::SharedCow;
 use reedline::Suggestion;
 use std::{collections::HashMap, sync::Arc};
 
@@ -17,6 +18,7 @@ use super::completion_options::NuMatcher;
 fn map_value_completions<'a>(
     list: impl Iterator<Item = &'a Value>,
     span: Span,
+    input_start: usize,
     offset: usize,
 ) -> Vec<SemanticSuggestion> {
     list.filter_map(move |x| {
@@ -38,7 +40,7 @@ fn map_value_completions<'a>(
         // Match for record values
         if let Ok(record) = x.as_record() {
             let mut suggestion = Suggestion {
-                value: String::from(""), // Initialize with empty string
+                value: String::from(""),
                 span: reedline::Span {
                     start: span.start - offset,
                     end: span.end - offset,
@@ -52,21 +54,16 @@ fn map_value_completions<'a>(
                 match key.as_str() {
                     "value" => {
                         value_type = value.get_type();
-                        // Convert the value to string
                         if let Ok(val_str) = value.coerce_string() {
-                            // Update the suggestion value
                             suggestion.value = val_str;
                         }
                     }
                     "description" => {
-                        // Convert the value to string
                         if let Ok(desc_str) = value.coerce_string() {
-                            // Update the suggestion value
                             suggestion.description = Some(desc_str);
                         }
                     }
                     "style" => {
-                        // Convert the value to string
                         suggestion.style = match value {
                             Value::String { val, .. } => Some(lookup_ansi_color_style(val)),
                             Value::Record { .. } => Some(color_record_to_nustyle(value)),
@@ -74,30 +71,21 @@ fn map_value_completions<'a>(
                         };
                     }
                     "span" => {
-                        if let Value::Record { val: span, .. } = value {
-                            let start = span
-                                .get("start")
-                                .and_then(|val| val.as_int().ok())
-                                .and_then(|x| usize::try_from(x).ok());
-                            let end = span
-                                .get("end")
-                                .and_then(|val| val.as_int().ok())
-                                .and_then(|x| usize::try_from(x).ok());
+                        if let Value::Record { val: span_rec, .. } = value {
                             // TODO: error on invalid spans?
-                            match (start, end) {
-                                (Some(start), Some(end)) => {
-                                    suggestion.span = reedline::Span {
-                                        start: start.min(end),
-                                        end,
-                                    };
-                                }
-                                (Some(start), None) => {
-                                    suggestion.span.start = start.min(suggestion.span.end);
-                                }
-                                (None, Some(end)) => {
-                                    suggestion.span.end = end.max(suggestion.span.start);
-                                }
-                                _ => (),
+                            if let Some(end) = read_span_field(span_rec, "end") {
+                                suggestion.span.end = suggestion.span.end.min(end + input_start);
+                            }
+                            if let Some(start) = read_span_field(span_rec, "start") {
+                                suggestion.span.start = start + input_start;
+                            }
+                            if suggestion.span.start > suggestion.span.end {
+                                suggestion.span.start = suggestion.span.end;
+                                log::error!(
+                                    "Custom span start ({}) is greater than end ({})",
+                                    suggestion.span.start,
+                                    suggestion.span.end
+                                );
                             }
                         }
                     }
@@ -116,6 +104,19 @@ fn map_value_completions<'a>(
     .collect()
 }
 
+fn read_span_field(span: &SharedCow<Record>, field: &str) -> Option<usize> {
+    let Ok(val) = span.get(field)?.as_int() else {
+        log::error!("Expected span field {field} to be int");
+        return None;
+    };
+    let Ok(val) = usize::try_from(val) else {
+        log::error!("Couldn't convert span {field} to usize");
+        return None;
+    };
+
+    Some(val)
+}
+
 pub struct CustomCompletion<T: Completer> {
     decl_id: DeclId,
     line: String,
@@ -180,6 +181,7 @@ impl<T: Completer> Completer for CustomCompletion<T> {
 
         let mut completion_options = orig_options.clone();
         let mut should_sort = true;
+        let mut should_filter = true;
 
         // Parse result
         let suggestions = match result.and_then(|data| data.into_value(span)) {
@@ -188,16 +190,31 @@ impl<T: Completer> Completer for CustomCompletion<T> {
                     let completions = val
                         .get("completions")
                         .and_then(|val| {
-                            val.as_list()
-                                .ok()
-                                .map(|it| map_value_completions(it.iter(), span, offset))
+                            val.as_list().ok().map(|it| {
+                                map_value_completions(
+                                    it.iter(),
+                                    span,
+                                    self.line_pos - self.line.len(),
+                                    offset,
+                                )
+                            })
                         })
                         .unwrap_or_default();
                     let options = val.get("options");
 
                     if let Some(Value::Record { val: options, .. }) = &options {
+                        if let Some(filter) =
+                            options.get("filter").and_then(|val| val.as_bool().ok())
+                        {
+                            should_filter = filter;
+                        }
+
                         if let Some(sort) = options.get("sort").and_then(|val| val.as_bool().ok()) {
                             should_sort = sort;
+
+                            if should_sort && !should_filter {
+                                log::warn!("Sorting won't happen because filtering is disabled.")
+                            };
                         }
 
                         if let Some(case_sensitive) = options
@@ -206,6 +223,7 @@ impl<T: Completer> Completer for CustomCompletion<T> {
                         {
                             completion_options.case_sensitive = case_sensitive;
                         }
+
                         let positional =
                             options.get("positional").and_then(|val| val.as_bool().ok());
                         if positional.is_some() {
@@ -229,7 +247,12 @@ impl<T: Completer> Completer for CustomCompletion<T> {
 
                     completions
                 }
-                Value::List { vals, .. } => map_value_completions(vals.iter(), span, offset),
+                Value::List { vals, .. } => map_value_completions(
+                    vals.iter(),
+                    span,
+                    self.line_pos - self.line.len(),
+                    offset,
+                ),
                 Value::Nothing { .. } => {
                     return self.fallback.fetch(
                         working_set,
@@ -254,6 +277,10 @@ impl<T: Completer> Completer for CustomCompletion<T> {
             }
         };
 
+        if !should_filter {
+            return suggestions;
+        }
+
         let mut matcher = NuMatcher::new(prefix, &completion_options, should_sort);
 
         for sugg in suggestions {
@@ -379,7 +406,10 @@ impl<'a> Completer for CommandWideCompletion<'a> {
         )
         .map(|p| p.body);
 
-        if let Some(results) = convert_whole_command_completion_results(offset, new_span, result) {
+        let command_span = working_set.get_span(self.expression.span_id);
+        if let Some(results) =
+            convert_whole_command_completion_results(offset, new_span, result, command_span)
+        {
             results
         } else {
             self.need_fallback = true;
@@ -394,6 +424,7 @@ fn convert_whole_command_completion_results(
     offset: usize,
     span: Span,
     result: Result<PipelineData, nu_protocol::ShellError>,
+    command_span: Span,
 ) -> Option<Vec<SemanticSuggestion>> {
     let value = match result.and_then(|pipeline_data| pipeline_data.into_value(span)) {
         Ok(value) => value,
@@ -415,7 +446,8 @@ fn convert_whole_command_completion_results(
     match value {
         Value::List { vals, .. } => Some(map_value_completions(
             vals.iter(),
-            Span::new(span.start, span.end),
+            span,
+            command_span.start - offset,
             offset,
         )),
         Value::Nothing { .. } => None,
