@@ -1,3 +1,4 @@
+mod arg_value_completion;
 mod attribute_completions;
 mod base;
 mod cell_path_completions;
@@ -15,8 +16,9 @@ mod operator_completions;
 mod static_completions;
 mod variable_completions;
 
+pub use arg_value_completion::ArgValueCompletion;
 pub use attribute_completions::{AttributableCompletion, AttributeCompletion};
-pub use base::{Completer, SemanticSuggestion, SuggestionKind};
+pub use base::{Completer, SemanticSuggestion};
 pub use cell_path_completions::CellPathCompletion;
 pub use command_completions::CommandCompletion;
 pub use completer::NuCompleter;
@@ -27,6 +29,7 @@ pub use dotnu_completions::DotNuCompletion;
 pub use exportable_completions::ExportableCompletion;
 pub use file_completions::FileCompletion;
 pub use flag_completions::FlagCompletion;
+pub use nu_protocol::SuggestionKind;
 pub use operator_completions::OperatorCompletion;
 pub use static_completions::StaticCompletion;
 pub use variable_completions::VariableCompletion;
