@@ -31,6 +31,7 @@ pub fn read_plugin_file(engine_state: &mut EngineState, plugin_file: Option<Span
         .is_some_and(|ext| ext == "nu")
     {
         report_shell_error(
+            None,
             engine_state,
             &ShellError::GenericError {
                 error: "Wrong plugin file format".into(),
@@ -78,6 +79,7 @@ pub fn read_plugin_file(engine_state: &mut EngineState, plugin_file: Option<Span
                     }
                 } else {
                     report_shell_error(
+                        None,
                         engine_state,
                         &ShellError::Io(IoError::new_internal_with_path(
                             err,
@@ -106,6 +108,7 @@ pub fn read_plugin_file(engine_state: &mut EngineState, plugin_file: Option<Span
             Err(err) => {
                 log::warn!("Failed to read plugin registry file: {err:?}");
                 report_shell_error(
+                    None,
                     engine_state,
                     &ShellError::GenericError {
                         error: format!(
@@ -141,7 +144,7 @@ pub fn read_plugin_file(engine_state: &mut EngineState, plugin_file: Option<Span
         nu_plugin_engine::load_plugin_file(&mut working_set, &contents, span);
 
         if let Err(err) = engine_state.merge_delta(working_set.render()) {
-            report_shell_error(engine_state, &err);
+            report_shell_error(None, engine_state, &err);
             return;
         }
 
@@ -176,6 +179,7 @@ pub fn add_plugin_file(engine_state: &mut EngineState, plugin_file: Option<Spann
             } else {
                 // It's an error if the directory for the plugin file doesn't exist.
                 report_parse_error(
+                    None,
                     &StateWorkingSet::new(engine_state),
                     &ParseError::FileNotFound(
                         path_dir.to_string_lossy().into_owned(),
@@ -198,6 +202,7 @@ pub fn eval_config_contents(
     config_path: PathBuf,
     engine_state: &mut EngineState,
     stack: &mut Stack,
+    strict_mode: bool,
 ) {
     if config_path.exists() & config_path.is_file() {
         let config_filename = config_path.to_string_lossy();
@@ -208,7 +213,7 @@ pub fn eval_config_contents(
             engine_state.file = Some(config_path.clone());
 
             // TODO: ignore this error?
-            let _ = eval_source(
+            let exit_code = eval_source(
                 engine_state,
                 stack,
                 &contents,
@@ -216,13 +221,16 @@ pub fn eval_config_contents(
                 PipelineData::empty(),
                 false,
             );
+            if exit_code != 0 && strict_mode {
+                std::process::exit(exit_code)
+            }
 
             // Restore the current active file.
             engine_state.file = prev_file;
 
             // Merge the environment in case env vars changed in the config
             if let Err(e) = engine_state.merge_env(stack) {
-                report_shell_error(engine_state, &e);
+                report_shell_error(Some(stack), engine_state, &e);
             }
         }
     }
@@ -256,6 +264,7 @@ pub fn migrate_old_plugin_file(engine_state: &EngineState) -> bool {
         Ok(old_contents) => old_contents,
         Err(err) => {
             report_shell_error(
+                None,
                 engine_state,
                 &ShellError::GenericError {
                     error: "Can't read old plugin file to migrate".into(),
@@ -333,6 +342,7 @@ pub fn migrate_old_plugin_file(engine_state: &EngineState) -> bool {
         .and_then(|file| contents.write_to(file, None))
     {
         report_shell_error(
+            None,
             &engine_state,
             &ShellError::GenericError {
                 error: "Failed to save migrated plugin file".into(),
