@@ -95,17 +95,17 @@ pub fn evaluate_file(
     let block = parse(&mut working_set, Some(file_path_str), &file, false);
 
     if let Some(warning) = working_set.parse_warnings.first() {
-        report_parse_warning(&working_set, warning);
+        report_parse_warning(None, &working_set, warning);
     }
 
     // If any parse errors were found, report the first error and exit.
     if let Some(err) = working_set.parse_errors.first() {
-        report_parse_error(&working_set, err);
+        report_parse_error(None, &working_set, err);
         std::process::exit(1);
     }
 
     if let Some(err) = working_set.compile_errors.first() {
-        report_compile_error(&working_set, err);
+        report_compile_error(None, &working_set, err);
         std::process::exit(1);
     }
 
