@@ -23,22 +23,6 @@ impl Highlighter for NuHighlighter {
     }
 }
 
-// <<<<<<< HEAD
-// =======
-//         let config = self.stack.get_config(&self.engine_state);
-//         let highlight_resolved_externals = config.highlight_resolved_externals;
-//         let mut working_set = StateWorkingSet::new(&self.engine_state);
-//         let block = parse(&mut working_set, None, line.as_bytes(), false);
-//         let (shapes, global_span_offset) = {
-//             let mut shapes = flatten_block(&working_set, &block);
-//             // Highlighting externals has a config point because of concerns that using which to resolve
-//             // externals may slow down things too much.
-//             if highlight_resolved_externals {
-//                 for (span, shape) in shapes.iter_mut() {
-//                     if let FlatShape::External(aliased_command_span) = *shape {
-//                         let str_contents = working_set.get_span_contents(aliased_command_span);
-// >>>>>>> df798b657 (Fix highlighting of aliases to external commands)
-
 /// Result of a syntax highlight operation
 #[derive(Default)]
 pub(crate) struct HighlightResult {
@@ -60,34 +44,11 @@ pub(crate) fn highlight_syntax(
     let highlight_resolved_externals = config.highlight_resolved_externals;
     let mut working_set = StateWorkingSet::new(engine_state);
     let block = parse(&mut working_set, None, line.as_bytes(), false);
-    let (shapes, global_span_offset) = {
-        let mut shapes = flatten_block(&working_set, &block);
-        // Highlighting externals has a config point because of concerns that using which to resolve
-        // externals may slow down things too much.
-        if highlight_resolved_externals {
-            for (span, shape) in shapes.iter_mut() {
-                if let FlatShape::External(aliased_command_span) = shape {
-                    let str_contents = working_set.get_span_contents(**aliased_command_span);
-                    let str_word = String::from_utf8_lossy(str_contents).to_string();
-                    let paths = env::path_str(engine_state, stack, *span).ok();
-                    let res = if let Ok(cwd) = engine_state.cwd(Some(stack)) {
-                        which::which_in(str_word, paths.as_ref(), cwd).ok()
-                    } else {
-                        which::which_in_global(str_word, paths.as_ref())
-                            .ok()
-                            .and_then(|mut i| i.next())
-                    };
-                    if res.is_some() {
-                        *shape = FlatShape::ExternalResolved;
-                    }
-                }
-            }
-        }
-        (shapes, engine_state.next_span_start())
-    };
-
+    // TODO: Traverse::flat_map based highlighting?
+    let shapes = flatten_block(&working_set, &block);
+    let global_span_offset = engine_state.next_span_start();
     let mut result = HighlightResult::default();
-    let mut last_seen_span = global_span_offset;
+    let mut last_seen_span_end = global_span_offset;
 
     let global_cursor_offset = cursor + global_span_offset;
     let matching_brackets_pos = find_matching_brackets(
@@ -98,24 +59,31 @@ pub(crate) fn highlight_syntax(
         global_cursor_offset,
     );
 
-    for shape in &shapes {
-        if shape.0.end <= last_seen_span
-            || last_seen_span < global_span_offset
-            || shape.0.start < global_span_offset
+    for (raw_span, flat_shape) in &shapes {
+        // NOTE: Currently we expand aliases while flattening for tasks such as completion
+        // https://github.com/nushell/nushell/issues/16944
+        let span = if let FlatShape::External(alias_span) = flat_shape {
+            alias_span
+        } else {
+            raw_span
+        };
+
+        if span.end <= last_seen_span_end
+            || last_seen_span_end < global_span_offset
+            || span.start < global_span_offset
         {
             // We've already output something for this span
             // so just skip this one
             continue;
         }
-        if shape.0.start > last_seen_span {
+        if span.start > last_seen_span_end {
             let gap = line
-                [(last_seen_span - global_span_offset)..(shape.0.start - global_span_offset)]
+                [(last_seen_span_end - global_span_offset)..(span.start - global_span_offset)]
                 .to_string();
             result.text.push((Style::new(), gap));
         }
-        let next_token = line
-            [(shape.0.start - global_span_offset)..(shape.0.end - global_span_offset)]
-            .to_string();
+        let next_token =
+            line[(span.start - global_span_offset)..(span.end - global_span_offset)].to_string();
 
         let mut add_colored_token = |shape: &FlatShape, text: String| {
             result
@@ -123,44 +91,46 @@ pub(crate) fn highlight_syntax(
                 .push((get_shape_color(shape.as_str(), &config), text));
         };
 
-        match shape.1 {
+        match flat_shape {
             FlatShape::Garbage => {
                 result.found_garbage.get_or_insert_with(|| {
                     Span::new(
-                        shape.0.start - global_span_offset,
-                        shape.0.end - global_span_offset,
+                        span.start - global_span_offset,
+                        span.end - global_span_offset,
                     )
                 });
-                add_colored_token(&shape.1, next_token)
+                add_colored_token(flat_shape, next_token)
+            }
+            FlatShape::External(_) => {
+                let mut true_shape = flat_shape.clone();
+                // Highlighting externals has a config point because of concerns that using which to resolve
+                // externals may slow down things too much.
+                if highlight_resolved_externals {
+                    // use `raw_span` here for aliased external calls
+                    let str_contents = working_set.get_span_contents(*raw_span);
+                    let str_word = String::from_utf8_lossy(str_contents).to_string();
+                    let paths = env::path_str(engine_state, stack, *raw_span).ok();
+                    let res = if let Ok(cwd) = engine_state.cwd(Some(stack)) {
+                        which::which_in(str_word, paths.as_ref(), cwd).ok()
+                    } else {
+                        which::which_in_global(str_word, paths.as_ref())
+                            .ok()
+                            .and_then(|mut i| i.next())
+                    };
+                    if res.is_some() {
+                        true_shape = FlatShape::ExternalResolved;
+                    }
+                }
+                add_colored_token(&true_shape, next_token);
             }
-            FlatShape::Nothing => add_colored_token(&shape.1, next_token),
-            FlatShape::Binary => add_colored_token(&shape.1, next_token),
-            FlatShape::Bool => add_colored_token(&shape.1, next_token),
-            FlatShape::Int => add_colored_token(&shape.1, next_token),
-            FlatShape::Float => add_colored_token(&shape.1, next_token),
-            FlatShape::Range => add_colored_token(&shape.1, next_token),
-            FlatShape::InternalCall(_) => add_colored_token(&shape.1, next_token),
-            FlatShape::External(_) => add_colored_token(&shape.1, next_token),
-            FlatShape::ExternalArg => add_colored_token(&shape.1, next_token),
-            FlatShape::ExternalResolved => add_colored_token(&shape.1, next_token),
-            FlatShape::Keyword => add_colored_token(&shape.1, next_token),
-            FlatShape::Literal => add_colored_token(&shape.1, next_token),
-            FlatShape::Operator => add_colored_token(&shape.1, next_token),
-            FlatShape::Signature => add_colored_token(&shape.1, next_token),
-            FlatShape::String => add_colored_token(&shape.1, next_token),
-            FlatShape::RawString => add_colored_token(&shape.1, next_token),
-            FlatShape::StringInterpolation => add_colored_token(&shape.1, next_token),
-            FlatShape::DateTime => add_colored_token(&shape.1, next_token),
             FlatShape::List
             | FlatShape::Table
             | FlatShape::Record
             | FlatShape::Block
             | FlatShape::Closure => {
-                let span = shape.0;
-                let shape = &shape.1;
                 let spans = split_span_by_highlight_positions(
                     line,
-                    span,
+                    *span,
                     &matching_brackets_pos,
                     global_span_offset,
                 );
@@ -168,31 +138,19 @@ pub(crate) fn highlight_syntax(
                     let start = part.start - span.start;
                     let end = part.end - span.start;
                     let text = next_token[start..end].to_string();
-                    let mut style = get_shape_color(shape.as_str(), &config);
+                    let mut style = get_shape_color(flat_shape.as_str(), &config);
                     if highlight {
                         style = get_matching_brackets_style(style, &config);
                     }
                     result.text.push((style, text));
                 }
             }
-
-            FlatShape::Filepath => add_colored_token(&shape.1, next_token),
-            FlatShape::Directory => add_colored_token(&shape.1, next_token),
-            FlatShape::GlobInterpolation => add_colored_token(&shape.1, next_token),
-            FlatShape::GlobPattern => add_colored_token(&shape.1, next_token),
-            FlatShape::Variable(_) | FlatShape::VarDecl(_) => {
-                add_colored_token(&shape.1, next_token)
-            }
-            FlatShape::Flag => add_colored_token(&shape.1, next_token),
-            FlatShape::Pipe => add_colored_token(&shape.1, next_token),
-            FlatShape::Redirection => add_colored_token(&shape.1, next_token),
-            FlatShape::Custom(..) => add_colored_token(&shape.1, next_token),
-            FlatShape::MatchPattern => add_colored_token(&shape.1, next_token),
+            _ => add_colored_token(flat_shape, next_token),
         }
-        last_seen_span = shape.0.end;
+        last_seen_span_end = span.end;
     }
 
-    let remainder = line[(last_seen_span - global_span_offset)..].to_string();
+    let remainder = line[(last_seen_span_end - global_span_offset)..].to_string();
     if !remainder.is_empty() {
         result.text.push((Style::new(), remainder));
     }
