@@ -54,7 +54,7 @@ impl Command for StrKebabCase {
         )
     }
 
-    fn examples(&self) -> Vec<Example> {
+    fn examples(&self) -> Vec<Example<'_>> {
         vec![
             Example {
                 description: "convert a string to kebab-case",
