@@ -43,15 +43,15 @@ impl Command for Metadata {
         let arg = call.positional_nth(stack, 0);
         let head = call.head;
 
-        if !matches!(input, PipelineData::Empty) {
-            if let Some(arg_expr) = arg {
-                return Err(ShellError::IncompatibleParameters {
-                    left_message: "pipeline input was provided".into(),
-                    left_span: head,
-                    right_message: "but a positional metadata expression was also given".into(),
-                    right_span: arg_expr.span,
-                });
-            }
+        if !matches!(input, PipelineData::Empty)
+            && let Some(arg_expr) = arg
+        {
+            return Err(ShellError::IncompatibleParameters {
+                left_message: "pipeline input was provided".into(),
+                left_span: head,
+                right_message: "but a positional metadata expression was also given".into(),
+                right_span: arg_expr.span,
+            });
         }
 
         match arg {
@@ -103,7 +103,7 @@ impl Command for Metadata {
         }
     }
 
-    fn examples(&self) -> Vec<Example> {
+    fn examples(&self) -> Vec<Example<'_>> {
         vec![
             Example {
                 description: "Get the metadata of a variable",
