@@ -1,6 +1,7 @@
 mod ast;
 mod debug_;
 mod env;
+mod experimental_options;
 mod explain;
 mod info;
 mod inspect;
@@ -21,6 +22,7 @@ mod view_span;
 pub use ast::Ast;
 pub use debug_::Debug;
 pub use env::DebugEnv;
+pub use experimental_options::DebugExperimentalOptions;
 pub use explain::Explain;
 pub use info::DebugInfo;
 pub use inspect::Inspect;
