@@ -97,6 +97,7 @@ pub fn add_shell_command_context(mut engine_state: EngineState) -> EngineState {
 
         // Misc
         bind_command! {
+            DeleteVar,
             Panic,
             Source,
             Tutor,
@@ -408,6 +409,7 @@ pub fn add_shell_command_context(mut engine_state: EngineState) -> EngineState {
             HttpPost,
             HttpPut,
             HttpOptions,
+            HttpPool,
             Port,
             VersionCheck,
         }
