@@ -7,7 +7,6 @@ mod open;
 mod rm;
 mod save;
 mod start;
-mod touch;
 mod ucp;
 mod umkdir;
 mod umv;
@@ -24,7 +23,6 @@ pub use mktemp::Mktemp;
 pub use rm::Rm;
 pub use save::Save;
 pub use start::Start;
-pub use touch::Touch;
 pub use ucp::UCp;
 pub use umkdir::UMkdir;
 pub use umv::UMv;
