@@ -42,7 +42,7 @@ impl Command for Flatten {
         flatten(engine_state, stack, call, input)
     }
 
-    fn examples(&self) -> Vec<Example> {
+    fn examples(&self) -> Vec<Example<'_>> {
         vec![
             Example {
                 description: "flatten a table",
