@@ -25,7 +25,7 @@ impl Command for Reverse {
         vec!["convert, inverse, flip"]
     }
 
-    fn examples(&self) -> Vec<Example> {
+    fn examples(&self) -> Vec<Example<'_>> {
         vec![
             Example {
                 example: "[0,1,2,3] | reverse",
