@@ -211,9 +211,7 @@ fn generate_key(engine_state: &EngineState, item: &ValueCounter) -> Result<Strin
     nuon::to_nuon(
         engine_state,
         &value,
-        nuon::ToStyle::Default,
-        Some(Span::unknown()),
-        false,
+        nuon::ToNuonConfig::default().span(Some(Span::unknown())),
     )
 }
 
