@@ -7,12 +7,49 @@ use std::collections::HashSet;
 #[derive(Clone)]
 pub struct ToMd;
 
+/// Defines how lists should be formatted in Markdown output
+#[derive(Clone, Copy, Default, PartialEq)]
+enum ListStyle {
+    /// No list markers, just plain text separated by newlines
+    None,
+    /// Ordered list using "1. ", "2. ", etc.
+    Ordered,
+    /// Unordered list using "* " (default)
+    #[default]
+    Unordered,
+}
+
+impl ListStyle {
+    const OPTIONS: &[&'static str] = &["ordered", "unordered", "none"];
+
+    fn from_str(s: &str) -> Option<Self> {
+        match s.to_ascii_lowercase().as_str() {
+            "ordered" => Some(Self::Ordered),
+            "unordered" => Some(Self::Unordered),
+            "none" => Some(Self::None),
+            _ => None,
+        }
+    }
+}
+
 struct ToMdOptions {
     pretty: bool,
     per_element: bool,
     center: Option<Vec<CellPath>>,
     escape_md: bool,
     escape_html: bool,
+    list_style: ListStyle,
+}
+
+/// Special markdown element types that can be represented as single-field records
+const SPECIAL_MARKDOWN_HEADERS: &[&str] = &["h1", "h2", "h3", "blockquote"];
+
+/// Check if a record represents a special markdown element (h1, h2, h3, blockquote)
+fn is_special_markdown_record(record: &nu_protocol::Record) -> bool {
+    record.len() == 1
+        && record.get_index(0).is_some_and(|(header, _)| {
+            SPECIAL_MARKDOWN_HEADERS.contains(&header.to_ascii_lowercase().as_str())
+        })
 }
 
 impl Command for ToMd {
@@ -50,6 +87,12 @@ impl Command for ToMd {
                 "Escapes both Markdown and HTML special characters",
                 Some('a'),
             )
+            .named(
+                "list",
+                SyntaxShape::String,
+                "Format lists as 'ordered' (1. 2. 3.), 'unordered' (* * *), or 'none'. Default: unordered",
+                Some('l'),
+            )
             .category(Category::Formats)
     }
 
@@ -81,9 +124,9 @@ impl Command for ToMd {
                 )),
             },
             Example {
-                description: "Render a list",
-                example: "[0 1 2] | to md --pretty",
-                result: Some(Value::test_string("0\n1\n2")),
+                description: "Render a list (unordered by default)",
+                example: "[0 1 2] | to md",
+                result: Some(Value::test_string("* 0\n* 1\n* 2")),
             },
             Example {
                 description: "Separate list into markdown tables",
@@ -113,6 +156,16 @@ impl Command for ToMd {
                     "| a | b |\n| --- | --- |\n| p | &lt;p&gt;Welcome to nushell&lt;&#x2f;p&gt; |",
                 )),
             },
+            Example {
+                description: "Render a list as an ordered markdown list",
+                example: "[one two three] | to md --list ordered",
+                result: Some(Value::test_string("1. one\n2. two\n3. three")),
+            },
+            Example {
+                description: "Render a list without markers",
+                example: "[one two three] | to md --list none",
+                result: Some(Value::test_string("one\ntwo\nthree")),
+            },
         ]
     }
 
@@ -131,6 +184,18 @@ impl Command for ToMd {
         let escape_html = call.has_flag(engine_state, stack, "escape-html")?;
         let escape_both = call.has_flag(engine_state, stack, "escape-all")?;
         let center: Option<Vec<CellPath>> = call.get_flag(engine_state, stack, "center")?;
+        let list_style_str: Option<Spanned<String>> = call.get_flag(engine_state, stack, "list")?;
+
+        let list_style = match &list_style_str {
+            Some(spanned) => {
+                ListStyle::from_str(&spanned.item).ok_or_else(|| ShellError::InvalidValue {
+                    valid: format!("one of {}", ListStyle::OPTIONS.join(", ")),
+                    actual: spanned.item.clone(),
+                    span: spanned.span,
+                })?
+            }
+            None => ListStyle::default(),
+        };
 
         let config = stack.get_config(engine_state);
 
@@ -142,6 +207,7 @@ impl Command for ToMd {
                 center,
                 escape_md: escape_md || escape_both,
                 escape_html: escape_html || escape_both,
+                list_style,
             },
             &config,
             head,
@@ -161,33 +227,99 @@ fn to_md(
         .unwrap_or_default()
         .with_content_type(Some("text/markdown".into()));
 
+    // Collect input to check if it's a simple list (no records/tables)
+    let values: Vec<Value> = input.into_iter().collect();
+
+    // Check if input is a simple list (no records, lists, or tables)
+    // Tables in nushell can be represented as List of Records or List of Lists
+    let is_simple_list = !values
+        .iter()
+        .any(|v| matches!(v, Value::Record { .. } | Value::List { .. }));
+
+    // For simple lists, use list_style formatting
+    if is_simple_list {
+        let result = values
+            .into_iter()
+            .enumerate()
+            .map(|(idx, val)| {
+                format_list_item(
+                    val,
+                    idx,
+                    options.list_style,
+                    options.escape_md,
+                    options.escape_html,
+                    config,
+                )
+            })
+            .collect::<Vec<String>>()
+            .join("")
+            .trim()
+            .to_string();
+        return Ok(Value::string(result, head).into_pipeline_data_with_metadata(Some(metadata)));
+    }
+
+    // For tables/records, use the grouping logic
+    let input = Value::list(values, head).into_pipeline_data();
     let (grouped_input, single_list) = group_by(input, head, config);
     if options.per_element || single_list {
         return Ok(Value::string(
             grouped_input
                 .into_iter()
-                .map(move |val| match val {
-                    Value::List { .. } => {
-                        format!(
-                            "{}\n\n",
-                            table(
-                                val.into_pipeline_data(),
-                                options.pretty,
-                                &options.center,
+                .scan(0usize, |list_idx, val| {
+                    Some(match &val {
+                        Value::List { .. } => {
+                            format!(
+                                "{}\n\n",
+                                table(
+                                    val.into_pipeline_data(),
+                                    options.pretty,
+                                    &options.center,
+                                    options.escape_md,
+                                    options.escape_html,
+                                    config
+                                )
+                            )
+                        }
+                        // For records, check if it's a special markdown element (h1, h2, etc.)
+                        Value::Record { val: record, .. } => {
+                            if is_special_markdown_record(record) {
+                                // Special markdown elements use fragment() directly
+                                fragment(
+                                    val,
+                                    options.pretty,
+                                    &options.center,
+                                    options.escape_md,
+                                    options.escape_html,
+                                    config,
+                                )
+                            } else {
+                                // Regular records are rendered as tables
+                                format!(
+                                    "{}\n\n",
+                                    fragment(
+                                        val,
+                                        options.pretty,
+                                        &options.center,
+                                        options.escape_md,
+                                        options.escape_html,
+                                        config
+                                    )
+                                )
+                            }
+                        }
+                        _ => {
+                            let result = format_list_item(
+                                val,
+                                *list_idx,
+                                options.list_style,
                                 options.escape_md,
                                 options.escape_html,
-                                config
-                            )
-                        )
-                    }
-                    other => fragment(
-                        other,
-                        options.pretty,
-                        &options.center,
-                        options.escape_md,
-                        options.escape_html,
-                        config,
-                    ),
+                                config,
+                            );
+                            *list_idx += 1;
+                            result
+                        }
+                    })
                 })
                 .collect::<Vec<String>>()
                 .join("")
@@ -210,6 +342,25 @@ fn to_md(
     .into_pipeline_data_with_metadata(Some(metadata)))
 }
 
+/// Formats a single list item with the appropriate list marker based on list_style
+fn format_list_item(
+    input: Value,
+    index: usize,
+    list_style: ListStyle,
+    escape_md: bool,
+    escape_html: bool,
+    config: &Config,
+) -> String {
+    let value_string = input.to_expanded_string("|", config);
+    let escaped = escape_value(value_string, escape_md, escape_html, false);
+
+    match list_style {
+        ListStyle::Ordered => format!("{}. {}\n", index + 1, escaped),
+        ListStyle::Unordered => format!("* {}\n", escaped),
+        ListStyle::None => format!("{}\n", escaped),
+    }
+}
+
 fn escape_markdown_characters(input: String, escape_md: bool, for_table: bool) -> String {
     let mut output = String::with_capacity(input.len());
     for ch in input.chars() {
@@ -233,6 +384,19 @@ fn escape_markdown_characters(input: String, escape_md: bool, for_table: bool) -
     output
 }
 
+/// Escapes a value string with optional HTML and Markdown escaping
+fn escape_value(value: String, escape_md: bool, escape_html: bool, for_table: bool) -> String {
+    escape_markdown_characters(
+        if escape_html {
+            v_htmlescape::escape(&value).to_string()
+        } else {
+            value
+        },
+        escape_md,
+        for_table,
+    )
+}
+
 fn fragment(
     input: Value,
     pretty: bool,
@@ -245,35 +409,19 @@ fn fragment(
 
     if let Value::Record { val, .. } = &input {
         match val.get_index(0) {
-            Some((header, data)) if val.len() == 1 => {
+            Some((header, data)) if is_special_markdown_record(val) => {
+                // SAFETY: is_special_markdown_record already validated the header matches one of these
                 let markup = match header.to_ascii_lowercase().as_ref() {
-                    "h1" => "# ".to_string(),
-                    "h2" => "## ".to_string(),
-                    "h3" => "### ".to_string(),
-                    "blockquote" => "> ".to_string(),
-                    _ => {
-                        return table(
-                            input.into_pipeline_data(),
-                            pretty,
-                            center,
-                            escape_md,
-                            escape_html,
-                            config,
-                        );
-                    }
+                    "h1" => "# ",
+                    "h2" => "## ",
+                    "h3" => "### ",
+                    "blockquote" => "> ",
+                    _ => "> ", // Fallback for any future validated headers not yet listed explicitly
                 };
 
                 let value_string = data.to_expanded_string("|", config);
-                out.push_str(&markup);
-                out.push_str(&escape_markdown_characters(
-                    if escape_html {
-                        v_htmlescape::escape(&value_string).to_string()
-                    } else {
-                        value_string
-                    },
-                    escape_md,
-                    false,
-                ));
+                out.push_str(markup);
+                out.push_str(&escape_value(value_string, escape_md, escape_html, false));
             }
             _ => {
                 out = table(
@@ -288,15 +436,7 @@ fn fragment(
         }
     } else {
         let value_string = input.to_expanded_string("|", config);
-        out = escape_markdown_characters(
-            if escape_html {
-                v_htmlescape::escape(&value_string).to_string()
-            } else {
-                value_string
-            },
-            escape_md,
-            false,
-        );
+        out = escape_value(value_string, escape_md, escape_html, false);
     }
 
     out.push('\n');
@@ -1225,4 +1365,183 @@ mod tests {
             "#)
         );
     }
+
+    #[test]
+    fn test_list_ordered() {
+        let value = Value::test_list(vec![
+            Value::test_string("one"),
+            Value::test_string("two"),
+            Value::test_string("three"),
+        ]);
+
+        let result = to_md(
+            value.into_pipeline_data(),
+            ToMdOptions {
+                pretty: false,
+                per_element: false,
+                center: None,
+                escape_md: false,
+                escape_html: false,
+                list_style: ListStyle::Ordered,
+            },
+            &Config::default(),
+            Span::test_data(),
+        )
+        .unwrap()
+        .into_value(Span::test_data())
+        .unwrap()
+        .into_string()
+        .unwrap();
+
+        assert_eq!(result, "1. one\n2. two\n3. three");
+    }
+
+    #[test]
+    fn test_list_unordered() {
+        let value = Value::test_list(vec![
+            Value::test_string("apple"),
+            Value::test_string("banana"),
+            Value::test_string("cherry"),
+        ]);
+
+        let result = to_md(
+            value.into_pipeline_data(),
+            ToMdOptions {
+                pretty: false,
+                per_element: false,
+                center: None,
+                escape_md: false,
+                escape_html: false,
+                list_style: ListStyle::Unordered,
+            },
+            &Config::default(),
+            Span::test_data(),
+        )
+        .unwrap()
+        .into_value(Span::test_data())
+        .unwrap()
+        .into_string()
+        .unwrap();
+
+        assert_eq!(result, "* apple\n* banana\n* cherry");
+    }
+
+    #[test]
+    fn test_list_with_escape_md() {
+        let value = Value::test_list(vec![
+            Value::test_string("*bold*"),
+            Value::test_string("[link]"),
+        ]);
+
+        let result = to_md(
+            value.into_pipeline_data(),
+            ToMdOptions {
+                pretty: false,
+                per_element: false,
+                center: None,
+                escape_md: true,
+                escape_html: false,
+                list_style: ListStyle::Unordered,
+            },
+            &Config::default(),
+            Span::test_data(),
+        )
+        .unwrap()
+        .into_value(Span::test_data())
+        .unwrap()
+        .into_string()
+        .unwrap();
+
+        assert_eq!(result, "* \\*bold\\*\n* \\[link\\]");
+    }
+
+    #[test]
+    fn test_list_none() {
+        let value = Value::test_list(vec![
+            Value::test_string("one"),
+            Value::test_string("two"),
+            Value::test_string("three"),
+        ]);
+
+        let result = to_md(
+            value.into_pipeline_data(),
+            ToMdOptions {
+                pretty: false,
+                per_element: false,
+                center: None,
+                escape_md: false,
+                escape_html: false,
+                list_style: ListStyle::None,
+            },
+            &Config::default(),
+            Span::test_data(),
+        )
+        .unwrap()
+        .into_value(Span::test_data())
+        .unwrap()
+        .into_string()
+        .unwrap();
+
+        assert_eq!(result, "one\ntwo\nthree");
+    }
+
+    #[test]
+    fn test_empty_list() {
+        let value = Value::test_list(vec![]);
+
+        let result = to_md(
+            value.into_pipeline_data(),
+            ToMdOptions {
+                pretty: false,
+                per_element: false,
+                center: None,
+                escape_md: false,
+                escape_html: false,
+                list_style: ListStyle::Unordered,
+            },
+            &Config::default(),
+            Span::test_data(),
+        )
+        .unwrap()
+        .into_value(Span::test_data())
+        .unwrap()
+        .into_string()
+        .unwrap();
+
+        assert_eq!(result, "");
+    }
+
+    #[test]
+    fn test_mixed_input_ordered() {
+        // Test that list numbering is continuous even with h1/tables mixed in
+        let value = Value::test_list(vec![
+            Value::test_record(record! {
+                "h1" => Value::test_string("Title"),
+            }),
+            Value::test_string("first"),
+            Value::test_string("second"),
+        ]);
+
+        let result = to_md(
+            value.into_pipeline_data(),
+            ToMdOptions {
+                pretty: false,
+                per_element: true,
+                center: None,
+                escape_md: false,
+                escape_html: false,
+                list_style: ListStyle::Ordered,
+            },
+            &Config::default(),
+            Span::test_data(),
+        )
+        .unwrap()
+        .into_value(Span::test_data())
+        .unwrap()
+        .into_string()
+        .unwrap();
+
+        // h1 should not affect numbering; items should be 1. and 2.
+        assert_eq!(result, "# Title\n1. first\n2. second");
+    }
 }
