@@ -1,7 +1,9 @@
 mod panic;
 mod source;
 mod tutor;
+mod unlet;
 
 pub use panic::Panic;
 pub use source::Source;
 pub use tutor::Tutor;
+pub use unlet::DeleteVar;
