@@ -5,6 +5,7 @@ mod head;
 mod http_;
 mod options;
 mod patch;
+mod pool;
 mod post;
 mod put;
 mod resolver;
@@ -17,5 +18,6 @@ pub use head::HttpHead;
 pub use http_::Http;
 pub use options::HttpOptions;
 pub use patch::HttpPatch;
+pub use pool::HttpPool;
 pub use post::HttpPost;
 pub use put::HttpPut;
