@@ -201,7 +201,7 @@ impl Command for Input {
         }
     }
 
-    fn examples(&self) -> Vec<Example> {
+    fn examples(&self) -> Vec<Example<'_>> {
         vec![
             Example {
                 description: "Get input from the user, and assign to a variable",
