@@ -1,7 +1,9 @@
 mod date;
 mod duration;
 mod filesize;
+mod format_;
 
-pub use self::filesize::FormatFilesize;
 pub use date::FormatDate;
 pub use duration::FormatDuration;
+pub use filesize::FormatFilesize;
+pub use format_::Format;
