@@ -134,7 +134,7 @@ impl Command for NuCheck {
         }
     }
 
-    fn examples(&self) -> Vec<Example> {
+    fn examples(&self) -> Vec<Example<'_>> {
         vec![
             Example {
                 description: "Parse a input file as script(Default)",
