@@ -1,16 +1,13 @@
 use nu_test_support::fs::Stub::EmptyFile;
+use nu_test_support::nu;
 use nu_test_support::playground::Playground;
-use nu_test_support::{nu, pipeline};
 
 #[test]
 fn returns_type_of_missing_file() {
-    let actual = nu!(
-        cwd: "tests", pipeline(
-        r#"
-            echo "spam.txt"
-            | path type
-        "#
-    ));
+    let actual = nu!(cwd: "tests", r#"
+        echo "spam.txt"
+        | path type
+    "#);
 
     assert_eq!(actual.out, "");
 }
@@ -20,13 +17,10 @@ fn returns_type_of_existing_file() {
     Playground::setup("path_expand_1", |dirs, sandbox| {
         sandbox.within("menu").with_files(&[EmptyFile("spam.txt")]);
 
-        let actual = nu!(
-            cwd: dirs.test(), pipeline(
-            r#"
-                echo "menu"
-                | path type
-            "#
-        ));
+        let actual = nu!(cwd: dirs.test(), r#"
+            echo "menu"
+            | path type
+        "#);
 
         assert_eq!(actual.out, "dir");
     })
@@ -37,22 +31,17 @@ fn returns_type_of_existing_directory() {
     Playground::setup("path_expand_1", |dirs, sandbox| {
         sandbox.within("menu").with_files(&[EmptyFile("spam.txt")]);
 
-        let actual = nu!(
-            cwd: dirs.test(), pipeline(
-            r#"
-                echo "menu/spam.txt"
-                | path type
-            "#
-        ));
+        let actual = nu!(cwd: dirs.test(), r#"
+            echo "menu/spam.txt"
+            | path type
+        "#);
 
         assert_eq!(actual.out, "file");
 
-        let actual = nu!(pipeline(
-            r#"
-                echo "~"
-                | path type
-            "#
-        ));
+        let actual = nu!(r#"
+            echo "~"
+            | path type
+        "#);
 
         assert_eq!(actual.out, "dir");
     })
@@ -63,13 +52,10 @@ fn returns_type_of_existing_file_const() {
     Playground::setup("path_type_const", |dirs, sandbox| {
         sandbox.within("menu").with_files(&[EmptyFile("spam.txt")]);
 
-        let actual = nu!(
-            cwd: dirs.test(), pipeline(
-            r#"
-                const ty = ("menu" | path type);
-                $ty
-            "#
-        ));
+        let actual = nu!(cwd: dirs.test(), r#"
+            const ty = ("menu" | path type);
+            $ty
+        "#);
 
         assert_eq!(actual.out, "dir");
     })
