@@ -47,3 +47,23 @@ fn tee_save_stderr_to_file() {
         assert_eq!("teststring\n", file_contents(dirs.test().join("copy.txt")));
     })
 }
+
+#[test]
+fn tee_single_value_streamable() {
+    let actual = nu!("'Hello, world!' | tee { print -e } | print");
+    assert!(actual.status.success());
+    assert_eq!("Hello, world!", actual.out);
+    // FIXME: note the lack of newline: this is a consequence of converting the string to a stream
+    // for now, but most likely the printer should be checking whether a string stream ends with a
+    // newline and adding it unless no_newline is true
+    assert_eq!("Hello, world!", actual.err);
+}
+
+#[test]
+fn tee_single_value_non_streamable() {
+    // Non-streamable values don't have any synchronization point, so we have to wait.
+    let actual = nu!("500 | tee { print -e } | print; sleep 1sec");
+    assert!(actual.status.success());
+    assert_eq!("500", actual.out);
+    assert_eq!("500\n", actual.err);
+}
