@@ -11,7 +11,8 @@ mod trailing_slash;
 
 pub use components::components;
 pub use expansions::{
-    canonicalize_with, expand_path, expand_path_with, expand_to_real_path, locate_in_dirs,
+    absolute_with, canonicalize_with, expand_path, expand_path_with, expand_to_real_path,
+    locate_in_dirs,
 };
 pub use helpers::{cache_dir, data_dir, home_dir, is_windows_device_path, nu_config_dir};
 pub use path::*;
