@@ -11,9 +11,10 @@ use nu_plugin_protocol::{
     PluginInput, PluginOption, PluginOutput, ProtocolInfo,
 };
 use nu_protocol::{
-    Config, DeclId, DynamicSuggestion, Handler, HandlerGuard, Handlers, LabeledError, PipelineData,
+    BlockId, Config, DeclId, DynamicSuggestion, Handler, HandlerGuard, Handlers, PipelineData,
     PluginMetadata, PluginSignature, ShellError, SignalAction, Signals, Span, Spanned, Value,
     engine::{Closure, Sequence},
+    ir::IrBlock,
 };
 use nu_utils::SharedCow;
 use std::{
@@ -424,7 +425,7 @@ impl EngineInterface {
     /// Write an OK call response or an error.
     pub(crate) fn write_ok(
         &self,
-        result: Result<(), impl Into<LabeledError>>,
+        result: Result<(), impl Into<ShellError>>,
     ) -> Result<(), ShellError> {
         let response = match result {
             Ok(()) => PluginCallResponse::Ok,
@@ -438,7 +439,7 @@ impl EngineInterface {
     /// to finish writing the stream
     pub(crate) fn write_response(
         &self,
-        result: Result<PipelineData, impl Into<LabeledError>>,
+        result: Result<PipelineData, impl Into<ShellError>>,
     ) -> Result<PipelineDataWriter<Self>, ShellError> {
         match result {
             Ok(data) => {
@@ -944,6 +945,34 @@ impl EngineInterface {
         }
     }
 
+    /// Get the compiled IR for a block.
+    ///
+    /// # Example
+    ///
+    /// ```rust,no_run
+    /// # use nu_protocol::{ShellError, Spanned};
+    /// # use nu_protocol::engine::Closure;
+    /// # use nu_plugin::EngineInterface;
+    /// # fn example(engine: &EngineInterface, closure: &Spanned<Closure>) -> Result<(), ShellError> {
+    /// let ir_block = engine.get_block_ir(closure.item.block_id)?;
+    /// for instruction in &ir_block.instructions {
+    ///     // ...
+    /// }
+    /// # Ok(())
+    /// # }
+    /// ```
+    pub fn get_block_ir(&self, block_id: BlockId) -> Result<IrBlock, ShellError> {
+        let call = EngineCall::GetBlockIR(block_id);
+
+        match self.engine_call(call)? {
+            EngineCallResponse::Error(err) => Err(err),
+            EngineCallResponse::IrBlock(ir) => Ok(*ir),
+            _ => Err(ShellError::PluginFailedToDecode {
+                msg: "Received unexpected response type for EngineCall::GetBlockIR".into(),
+            }),
+        }
+    }
+
     /// Ask the engine to call an internal command, using the declaration ID previously looked up
     /// with [`.find_decl()`](Self::find_decl).
     ///
