@@ -3,11 +3,12 @@ mod argument;
 mod cached_file;
 mod call;
 mod call_info;
-mod capture_block;
+mod closure;
 mod command;
 mod description;
 mod engine_state;
 mod error_handler;
+mod jobs;
 mod overlay;
 mod pattern_match;
 mod sequence;
@@ -22,10 +23,11 @@ pub use cached_file::CachedFile;
 pub use argument::*;
 pub use call::*;
 pub use call_info::*;
-pub use capture_block::*;
+pub use closure::*;
 pub use command::*;
 pub use engine_state::*;
 pub use error_handler::*;
+pub use jobs::*;
 pub use overlay::*;
 pub use pattern_match::*;
 pub use sequence::*;
