@@ -194,7 +194,7 @@ impl<'a> StateWorkingSet<'a> {
     }
 
     pub fn merge_predecl(&mut self, name: &[u8]) -> Option<DeclId> {
-        self.move_predecls_to_overlay();
+        self.move_one_predecl_to_overlay(name);
 
         let overlay_frame = self.last_overlay_mut();
 
@@ -207,11 +207,12 @@ impl<'a> StateWorkingSet<'a> {
         None
     }
 
-    fn move_predecls_to_overlay(&mut self) {
-        let predecls: HashMap<Vec<u8>, DeclId> =
-            self.delta.last_scope_frame_mut().predecls.drain().collect();
-
-        self.last_overlay_mut().predecls.extend(predecls);
+    fn move_one_predecl_to_overlay(&mut self, name: &[u8]) {
+        self.delta
+            .last_scope_frame_mut()
+            .predecls
+            .remove_entry(name)
+            .map(|(name, decl_id)| self.last_overlay_mut().predecls.insert(name, decl_id));
     }
 
     pub fn hide_decl(&mut self, name: &[u8]) -> Option<DeclId> {
@@ -942,8 +943,6 @@ impl<'a> StateWorkingSet<'a> {
             .retain(|id| id != &overlay_id);
         last_scope_frame.active_overlays.push(overlay_id);
 
-        self.move_predecls_to_overlay();
-
         self.use_decls(definitions.decls);
         self.use_modules(definitions.modules);
 
