@@ -37,6 +37,10 @@ where
     }
 }
 
+impl<M> Id<M, usize> {
+    pub const ZERO: Self = Self::new(0);
+}
+
 impl<M, V> Debug for Id<M, V>
 where
     V: Display,
@@ -115,6 +119,12 @@ pub type JobId = Id<marker::Job>;
 /// Note: `%0` is allocated with the block input at the beginning of a compiled block.
 pub type RegId = Id<marker::Reg, u32>;
 
+impl Display for JobId {
+    fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
+        write!(f, "{}", self.inner)
+    }
+}
+
 impl Display for RegId {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         write!(f, "%{}", self.get())
