@@ -73,21 +73,21 @@ pub fn collect_proc(interval: Duration, _with_thread: bool) -> Vec<ProcessInfo>
         let fds = listpidinfo::<ListFDs>(pid, curr_task.pbsd.pbi_nfiles as usize);
         if let Ok(fds) = fds {
             for fd in fds {
-                if let ProcFDType::Socket = fd.proc_fdtype.into() {
-                    if let Ok(socket) = pidfdinfo::<SocketFDInfo>(pid, fd.proc_fd) {
-                        match socket.psi.soi_kind.into() {
-                            SocketInfoKind::In => {
-                                if socket.psi.soi_protocol == libc::IPPROTO_UDP {
-                                    let info = unsafe { socket.psi.soi_proto.pri_in };
-                                    curr_udps.push(info);
-                                }
+                if let ProcFDType::Socket = fd.proc_fdtype.into()
+                    && let Ok(socket) = pidfdinfo::<SocketFDInfo>(pid, fd.proc_fd)
+                {
+                    match socket.psi.soi_kind.into() {
+                        SocketInfoKind::In => {
+                            if socket.psi.soi_protocol == libc::IPPROTO_UDP {
+                                let info = unsafe { socket.psi.soi_proto.pri_in };
+                                curr_udps.push(info);
                             }
-                            SocketInfoKind::Tcp => {
-                                let info = unsafe { socket.psi.soi_proto.pri_tcp };
-                                curr_tcps.push(info);
-                            }
-                            _ => (),
                         }
+                        SocketInfoKind::Tcp => {
+                            let info = unsafe { socket.psi.soi_proto.pri_tcp };
+                            curr_tcps.push(info);
+                        }
+                        _ => (),
                     }
                 }
             }
@@ -199,11 +199,11 @@ fn get_path_info(pid: i32, mut size: size_t) -> Option<PathInfo> {
                     .to_owned();
                 let mut need_root = true;
                 let mut root = Default::default();
-                if exe.is_absolute() {
-                    if let Some(parent) = exe.parent() {
-                        root = parent.to_path_buf();
-                        need_root = false;
-                    }
+                if exe.is_absolute()
+                    && let Some(parent) = exe.parent()
+                {
+                    root = parent.to_path_buf();
+                    need_root = false;
                 }
                 while cp < ptr.add(size) && *cp == 0 {
                     cp = cp.offset(1);
