@@ -10,7 +10,7 @@ pub mod common;
 
 pub use common::{StringResult, TableResult};
 pub use nu_color_config::TextStyle;
-pub use table::{NuRecordsValue, NuTable};
+pub use table::{NuRecords, NuRecordsValue, NuTable};
 pub use table_theme::TableTheme;
 pub use types::{CollapsedTable, ExpandedTable, JustTable, TableOpts, TableOutput};
 pub use unstructured_table::UnstructuredTable;
