@@ -1,11 +1,4 @@
 use crate::playground::Playground;
-use std::path::{Path, PathBuf};
-
-fn path(p: &Path) -> PathBuf {
-    let cwd = std::env::current_dir().expect("Could not get current working directory.");
-    nu_path::canonicalize_with(p, cwd)
-        .unwrap_or_else(|e| panic!("Couldn't canonicalize path {}: {:?}", p.display(), e))
-}
 
 #[test]
 fn current_working_directory_in_sandbox_directory_created() {
@@ -13,7 +6,7 @@ fn current_working_directory_in_sandbox_directory_created() {
         let original_cwd = dirs.test();
         nu.within("some_directory_within");
 
-        assert_eq!(path(nu.cwd()), original_cwd.join("some_directory_within"));
+        assert_eq!(nu.cwd(), original_cwd.join("some_directory_within"));
     })
 }
 
@@ -25,6 +18,6 @@ fn current_working_directory_back_to_root_from_anywhere() {
         nu.within("some_directory_within");
         nu.back_to_playground();
 
-        assert_eq!(path(nu.cwd()), *original_cwd);
+        assert_eq!(nu.cwd(), original_cwd);
     })
 }
