@@ -1,4 +1,4 @@
-use nu_plugin::{serve_plugin, MsgPackSerializer};
+use nu_plugin::{MsgPackSerializer, serve_plugin};
 use nu_plugin_formats::FormatCmdsPlugin;
 
 fn main() {
