@@ -1,29 +1,25 @@
 use nu_protocol::ShellError;
 use polars::prelude::PlPath;
-use polars_io::cloud::CloudOptions;
-use polars_utils::plpath::CloudScheme;
+use polars_io::cloud::{CloudOptions, CloudType};
 
 use crate::PolarsPlugin;
 
 mod aws;
-
-enum CloudType {
-    Aws,
-}
-
-fn determine_cloud_type(plpath: &PlPath) -> Option<CloudType> {
-    match plpath.cloud_scheme() {
-        Some(CloudScheme::S3) | Some(CloudScheme::S3a) => Some(CloudType::Aws),
-        _ => None,
-    }
-}
+mod azure;
+mod gcp;
 
 pub(crate) fn build_cloud_options(
     plugin: &PolarsPlugin,
     path: &PlPath,
 ) -> Result<Option<CloudOptions>, ShellError> {
-    match determine_cloud_type(path) {
+    match path
+        .cloud_scheme()
+        .map(|ref scheme| CloudType::from_cloud_scheme(scheme))
+    {
         Some(CloudType::Aws) => aws::build_cloud_options(plugin).map(Some),
+        Some(CloudType::Azure) => azure::build_cloud_options().map(Some),
+        Some(CloudType::Gcp) => gcp::build_cloud_options().map(Some),
+
         _ => Ok(None),
     }
 }
