@@ -138,12 +138,12 @@ impl PluginCommand for SaveDF {
 
 fn command(
     plugin: &PolarsPlugin,
-    _engine: &EngineInterface,
+    engine: &EngineInterface,
     call: &EvaluatedCall,
     polars_object: PolarsPluginObject,
     spanned_file: Spanned<String>,
 ) -> Result<PipelineData, ShellError> {
-    let resource = Resource::new(plugin, &spanned_file)?;
+    let resource = Resource::new(plugin, engine, &spanned_file)?;
     let type_option: Option<(String, Span)> = call
         .get_flag("type")?
         .map(|t: Spanned<String>| (t.item, t.span))
