@@ -99,6 +99,63 @@ impl PluginCommand for LazySelect {
                     .into_value(Span::test_data()),
                 ),
             },
+            Example {
+                description: "Select all columns from a dataframe using a selector",
+                example: "[[a b]; [6 2] [4 2] [2 2]] | polars into-df | polars select (polars selector all)",
+                result: Some(
+                    NuDataFrame::try_from_columns(
+                        vec![
+                            Column::new(
+                                "a".to_string(),
+                                vec![Value::test_int(6), Value::test_int(4), Value::test_int(2)],
+                            ),
+                            Column::new(
+                                "b".to_string(),
+                                vec![Value::test_int(2), Value::test_int(2), Value::test_int(2)],
+                            ),
+                        ],
+                        None,
+                    )
+                    .expect("simple df for test should not fail")
+                    .into_value(Span::test_data()),
+                ),
+            },
+            Example {
+                description: "Select columns by name using a selector",
+                example: "[[a b c]; [1 2 3] [4 5 6]] | polars into-df | polars select (polars selector by-name a c)",
+                result: Some(
+                    NuDataFrame::try_from_columns(
+                        vec![
+                            Column::new(
+                                "a".to_string(),
+                                vec![Value::test_int(1), Value::test_int(4)],
+                            ),
+                            Column::new(
+                                "c".to_string(),
+                                vec![Value::test_int(3), Value::test_int(6)],
+                            ),
+                        ],
+                        None,
+                    )
+                    .expect("simple df for test should not fail")
+                    .into_value(Span::test_data()),
+                ),
+            },
+            Example {
+                description: "Select the first column using a selector",
+                example: "[[a b c]; [1 2 3] [4 5 6]] | polars into-df | polars select (polars selector first)",
+                result: Some(
+                    NuDataFrame::try_from_columns(
+                        vec![Column::new(
+                            "a".to_string(),
+                            vec![Value::test_int(1), Value::test_int(4)],
+                        )],
+                        None,
+                    )
+                    .expect("simple df for test should not fail")
+                    .into_value(Span::test_data()),
+                ),
+            },
         ]
     }
 
