@@ -10,7 +10,7 @@ use command::{
     aggregation::aggregation_commands, boolean::boolean_commands,
     computation::computation_commands, core::core_commands, data::data_commands,
     datetime::datetime_commands, index::index_commands, integer::integer_commands,
-    list::list_commands, string::string_commands, stub::PolarsCmd,
+    list::list_commands, selector::selector_commands, string::string_commands, stub::PolarsCmd,
 };
 use log::debug;
 use nu_plugin::{EngineInterface, Plugin, PluginCommand};
@@ -97,6 +97,7 @@ impl Plugin for PolarsPlugin {
         commands.append(&mut datetime_commands());
         commands.append(&mut index_commands());
         commands.append(&mut integer_commands());
+        commands.append(&mut selector_commands());
         commands.append(&mut string_commands());
         commands.append(&mut list_commands());
 
@@ -130,6 +131,7 @@ impl Plugin for PolarsPlugin {
             CustomValueType::NuWhen(cv) => cv.custom_value_to_base_value(self, engine),
             CustomValueType::NuDataType(cv) => cv.custom_value_to_base_value(self, engine),
             CustomValueType::NuSchema(cv) => cv.custom_value_to_base_value(self, engine),
+            CustomValueType::NuSelector(cv) => cv.custom_value_to_base_value(self, engine),
         };
         Ok(result?)
     }
@@ -163,6 +165,9 @@ impl Plugin for PolarsPlugin {
             CustomValueType::NuSchema(cv) => {
                 cv.custom_value_operation(self, engine, left.span, operator, right)
             }
+            CustomValueType::NuSelector(cv) => {
+                cv.custom_value_operation(self, engine, left.span, operator, right)
+            }
         };
         Ok(result?)
     }
@@ -197,6 +202,9 @@ impl Plugin for PolarsPlugin {
             CustomValueType::NuSchema(cv) => {
                 cv.custom_value_follow_path_int(self, engine, custom_value.span, index)
             }
+            CustomValueType::NuSelector(cv) => {
+                cv.custom_value_follow_path_int(self, engine, custom_value.span, index)
+            }
         };
         Ok(result?)
     }
@@ -232,6 +240,9 @@ impl Plugin for PolarsPlugin {
             CustomValueType::NuSchema(cv) => {
                 cv.custom_value_follow_path_string(self, engine, custom_value.span, column_name)
             }
+            CustomValueType::NuSelector(cv) => {
+                cv.custom_value_follow_path_string(self, engine, custom_value.span, column_name)
+            }
         };
         Ok(result?)
     }
@@ -260,6 +271,9 @@ impl Plugin for PolarsPlugin {
                 cv.custom_value_partial_cmp(self, engine, other_value)
             }
             CustomValueType::NuSchema(cv) => cv.custom_value_partial_cmp(self, engine, other_value),
+            CustomValueType::NuSelector(cv) => {
+                cv.custom_value_partial_cmp(self, engine, other_value)
+            }
         };
         Ok(result?)
     }
