@@ -1,4 +1,4 @@
-use nu_plugin::{serve_plugin, JsonSerializer};
+use nu_plugin::{JsonSerializer, serve_plugin};
 use nu_plugin_query::Query;
 
 fn main() {
