@@ -5,7 +5,6 @@ mod experimental_options;
 mod ide;
 mod logger;
 mod run;
-#[cfg(not(feature = "mcp"))]
 mod signals;
 #[cfg(unix)]
 mod terminal;
@@ -31,7 +30,6 @@ use nu_protocol::{
 use nu_std::load_standard_library;
 use nu_utils::perf;
 use run::{run_commands, run_file, run_repl};
-#[cfg(not(feature = "mcp"))]
 use signals::ctrlc_protection;
 use std::{borrow::Cow, path::PathBuf, str::FromStr, sync::Arc};
 
@@ -73,7 +71,7 @@ fn main() -> Result<()> {
     let (args_to_nushell, script_name, args_to_script) = gather_commandline_args();
     let parsed_nu_cli_args = parse_commandline_args(&args_to_nushell.join(" "), &mut engine_state)
         .unwrap_or_else(|err| {
-            report_shell_error(&engine_state, &err);
+            report_shell_error(None, &engine_state, &err);
             std::process::exit(1)
         });
 
@@ -99,12 +97,16 @@ fn main() -> Result<()> {
     };
 
     if let Err(err) = engine_state.merge_delta(delta) {
-        report_shell_error(&engine_state, &err);
+        report_shell_error(None, &engine_state, &err);
     }
 
-    // TODO: make this conditional in the future
+    #[cfg(feature = "mcp")]
+    let handle_ctrlc = !parsed_nu_cli_args.mcp;
     #[cfg(not(feature = "mcp"))]
-    ctrlc_protection(&mut engine_state);
+    let handle_ctrlc = true;
+    if handle_ctrlc {
+        ctrlc_protection(&mut engine_state);
+    }
 
     #[cfg(all(feature = "rustls-tls", feature = "network"))]
     nu_command::tls::CRYPTO_PROVIDER.default();
@@ -123,6 +125,7 @@ fn main() -> Result<()> {
                 .join("nushell")
         {
             report_shell_error(
+                None,
                 &engine_state,
                 &ShellError::InvalidXdgConfig {
                     xdg: xdg_config_home,
@@ -335,7 +338,7 @@ fn main() -> Result<()> {
     let use_color = config.use_ansi_coloring.get(&engine_state);
     // Translate environment variables from Strings to Values
     if let Err(e) = convert_env_values(&mut engine_state, &mut stack) {
-        report_shell_error(&engine_state, &e);
+        report_shell_error(None, &engine_state, &e);
     }
     perf!("Convert path to list", start_time, use_color);
 
